#ifndef GENERIC_FI_H
#define GENERIC_FI_H

/* Compilers may use another function within the assert macro to exit the 
 * program. QAC thus does not see an "exit" function and assumes the 
 * function returns, which it does not.
 * The below pragma tells QAC the compiler supplied function does not
 * return.
 */

/* examples - GCC, ICC, BCC 3.1, BCC 5.5, CYGWIN gcc, Watcom 1.6 */
#pragma PRQA_NO_RETURN __assert_fail
#pragma PRQA_NO_RETURN __assert_perror_fail
#pragma PRQA_NO_RETURN __assert

/* SDCC, BCC 5.5, Digital Mars DM 8.4, LCC, Watcom 1.6, Fujitsu F2MM,FR */
#pragma PRQA_NO_RETURN _assert

/* HI-TECH PCCLite */
#pragma PRQA_NO_RETURN _fassert

/* DJGPP, D.J.Delorie gcc DOS port */
#pragma PRQA_NO_RETURN __dj_assert

/* Watcom 1.6, MSVS 08 */
#pragma PRQA_NO_RETURN _wassert
#pragma PRQA_NO_RETURN __wassert
#pragma PRQA_NO_RETURN _assert99
#pragma PRQA_NO_RETURN _wassert99
#pragma PRQA_NO_RETURN __assert99
#pragma PRQA_NO_RETURN __wassert99

/* Renesas M32R compiler */
#pragma PRQA_NO_RETURN _Assert

/* NEC 78K0 series 16bit compiler */
#pragma PRQA_NO_RETURN __assertfail
#pragma PRQA_NO_RETURN __assertfail_n
#pragma PRQA_NO_RETURN __assertfail_f


/* Depending on the code that the compiler maker uses within the assert macro,
 * QAC may issue warnings. It is also possible that when the NDEBUG macro is used
 * to suppress the assertion code, QAC may issue a "no side-effects" warning.
 * To eliminate these, we turn off all warnings for the assert macro.
 */
#pragma PRQA_MACRO_MESSAGES_OFF "assert"


/* Any other items that may be required in a "force-include" file should be placed below. */

int __builtin_add_sat(int, int);
int __builtin_abs(int);
int __builtin_addbitrev(int, int);
int __builtin_avg(int, int);
int __builtin_clip(int, int);
int __builtin_count_ones(int);
int __builtin_fext(int, int);
int __builtin_frmul(int, int);
int __builtin_frmul_sat(int, int);
int __builtin_max(int, int);
int __builtin_min(int, int);
int __builtin_neg_sat(int);
int __builtin_sub_sat(int, int);
float __builtin_conv_RtoF(int);
float __builtin_copysignf(float, float);
float __builtin_fabsf(float);
float __builtin_favgf(float, float);
float __builtin_fclipf(float, float);
float __builtin_fmaxf(float, float);
float __builtin_fminf(float, float);
int __builtin_conv_FtoR(float);
long long __builtin_llabs(long long);
long long __builtin_llavg(long long, long long);
long long __builtin_llclip(long long, long long);
int __builtin_llcount_ones(long long);
long long __builtin_llmax(long long, long long);
long long __builtin_llmin(long long, long long);
int __builtin_abs_2x16(int);
int __builtin_add_2x16(int, int);
int __builtin_add_2x16_sat(int, int);
int __builtin_clip_2x16(int, int);
int __builtin_cmult_fr2x16(int, int);
int __builtin_cmult_i2x16(int, int);
int __builtin_max_2x16(int, int);
int __builtin_min_2x16(int, int);
int __builtin_mult_fr2x16(int, int);
int __builtin_mult_i2x16(int, int);
int __builtin_neg_2x16(int);
int __builtin_sub_2x16(int, int);
int __builtin_sub_2x16_sat(int, int);
int __builtin_sum_2x16(int);
int __builtin_compact_to_fr2x16(long long);
long long __builtin_expand_fr2x16(int);
int __builtin_compact_to_i2x16(long long);
long long __builtin_expand_i2x16(int);
long long __builtin_merge_2x16(int, int);
long long __builtin_abs_4x16(long long);
long long __builtin_add_4x16(long long, long long);
long long __builtin_add_4x16_sat(long long, long long);
long long __builtin_clip_4x16(long long, long long);
long long __builtin_max_4x16(long long, long long);
long long __builtin_min_4x16(long long, long long);
long long __builtin_mult_fr4x16(long long, long long);
long long __builtin_mult_fr4x16_sat(long long, long long); SRsd = Rmd * Rnd (S);
long long __builtin_mult_i4x16(long long, long long);
long long __builtin_neg_4x16(long long);
long long __builtin_sub_4x16(long long, long long);
long long __builtin_sub_4x16_sat(long long, long long);
int __builtin_sum_4x16(long long);
int __builtin_abs_4x8(int);
int __builtin_add_4x8(int, int);
int __builtin_add_4x8_sat(int, int);
int __builtin_clip_4x8(int, int);
int __builtin_max_4x8(int, int);
int __builtin_min_4x8(int, int);
int __builtin_sub_4x8(int, int);
int __builtin_sub_4x8_sat(int, int);
int __builtin_sum_4x8(int);
long long __builtin_merge_4x8(int, int);
long long __builtin_abs_8x8(long long);
long long __builtin_add_8x8(long long, long long);
long long __builtin_add_8x8_sat(long long, long long);
long long __builtin_clip_8x8(long long, long long);
long long __builtin_max_8x8(long long, long long);
long long __builtin_min_8x8(long long, long long);
long long __builtin_sub_8x8(long long, long long);
long long __builtin_sub_8x8_sat(long long, long long);
int __builtin_sum_8x8(long long);
long long __builtin_compose_64(int hi, int lo);
unsigned long long __builtin_compose_64u(unsigned, unsigned);
long double __builtin_f_compose_64(float, float);
int __builtin_high_32(long long);
unsigned __builtin_high_32u(unsigned long long);
float __builtin_f_high_32(long double);
int __builtin_low_32(long long);
unsigned __builtin_low_32u(unsigned long long);
float __builtin_f_low_32(long double);
int __builtin_high_64(__builtin_quad);
int __builtin_low_64(__builtin_quad);
int __builtin_sysreg_read(int);
long long __builtin_sysreg_read2(int);
void __builtin_sysreg_read(int);
void __builtin_sysreg_read2(long long);
void __builtin_sysreg_read4(__builtin_quad);
void * __builtin_alloca_aligned(int, int);
void __builtin_assert(int);

#else
#error "Multiple include"
#endif  /* ifndef GENERIC_FI_H */




